# Extracting Analytics Data from a Chatbot Instance

## Prerequisites

- Dashboard Key
- Python 3.7 or later


## Procedure

1. Install Python 3.7 if not present
2. Obtain your dashboard access token
3. Run CLI to dump the respective data source

## Configuration
This configuration file needs to be name `.avaamo` and stored in the current directory where
you run the CLI or in your home director.y


````
[avaamo]
bot_id=
dashboard_access_token=
endpoint=c0.avaamo.com=
